/*-
 * Copyright (c) 2013 Nathanial Sloss <nathanialsloss@yahoo.com.au>
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY THE NETBSD FOUNDATION, INC. AND CONTRIBUTORS
 * ``AS IS'' AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED
 * TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED.  IN NO EVENT SHALL THE FOUNDATION OR CONTRIBUTORS
 * BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE.
 */

#include <sys/ioctl.h>

#include <err.h>
#include <fcntl.h>
#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <unistd.h>

#include <dev/wscons/wsconsio.h>

int main(int argc, char *argv[]) {
	int fd, errno, bytesRead;
	struct wscons_event event;
	char fileName[256] = "/dev/wsmouse1";
	if (argc > 1)
		strncpy(fileName, argv[1], 256); 
	fd = open(fileName, O_RDWR|O_NONBLOCK);
	if (fd < 0) {
		err(errno, "Error opening %s", fileName);
		return EXIT_FAILURE;
	}
	for (;;) {
		bytesRead = read(fd, &event, sizeof(event));

		if (bytesRead = sizeof(event)) {
			/* Absolute events. */
			if (event.type == WSCONS_EVENT_MOUSE_ABSOLUTE_X)
				printf("ABSOLUTE_X: %d\n", event.value);

			if (event.type == WSCONS_EVENT_MOUSE_ABSOLUTE_Y)
				printf("ABSOLUTE_Y: %d\n", event.value);

			/* Relative events. */
			if (event.type == WSCONS_EVENT_MOUSE_DELTA_X)
				printf("DELTA_X: %d\n", event.value);

			if (event.type == WSCONS_EVENT_MOUSE_DELTA_Y)
				printf("DELTA_Y: %d\n", event.value);

			/* Button events. */
			if (event.type == WSCONS_EVENT_MOUSE_UP)
				printf("BUTTON_UP: %d\n", event.value);

			if (event.type == WSCONS_EVENT_MOUSE_DOWN)
				printf("BUTTON_DOWN: %d\n", event.value);
		}
	}

	close(fd);
	return EXIT_SUCCESS;
}
